
import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRound(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round'], 'items': [{'circle': {'cx': '12', 'cy': '8', 'r': '5'}}, {'path': {'d': 'M20 21a8 8 0 0 0-16 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GalleryVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-gallery-vertical'], 'items': [{'path': {'d': 'M3 2h18'}}, {'rect': {'width': '18', 'height': '12', 'x': '3', 'y': '6', 'rx': '2'}}, {'path': {'d': 'M3 22h18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield



from tagflow import document
import icons


kebab_to_pascal = lambda s: ''.join(w.capitalize() for w in s.split('-'))


def get_icon(name: str, render: bool = True, **kwargs):
  
    try:
        icon_class = getattr(icons, name, None)

        if not icon_class:
            icon_class_name = kebab_to_pascal(name)
            icon_class = getattr(icons, icon_class_name)
            
        if not render :
            return icon_class
        
        # Create an icon instance using lucide.create_icon
        with document() as doc:            
            with icon_class(**kwargs):
                pass

        # Return the SVG string
        return doc.to_html() 
    except Exception as e:
        # In case the icon name is invalid or another error occurs
        print(f"Error rendering lucide icon '{name}': {e}")
        return f'<!-- lucide icon "{name}" not found -->'    




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GitCommitHorizontal(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-git-commit-horizontal'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '3'}}, {'line': {'x1': '3', 'x2': '9', 'y1': '12', 'y2': '12'}}, {'line': {'x1': '15', 'x2': '21', 'y1': '12', 'y2': '12'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChevronLeft(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chevron-left'], 'items': [{'path': {'d': 'm15 18-6-6 6-6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Eclipse(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-eclipse'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M12 2a7 7 0 1 0 10 10'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BetweenHorizontalEnd(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-between-horizontal-end'], 'items': [{'rect': {'width': '13', 'height': '7', 'x': '3', 'y': '3', 'rx': '1'}}, {'path': {'d': 'm22 15-3-3 3-3'}}, {'rect': {'width': '13', 'height': '7', 'x': '3', 'y': '14', 'rx': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Globe(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-globe'], 'items': [{'circle': {'cx': '12', 'cy': '12', 'r': '10'}}, {'path': {'d': 'M12 2a14.5 14.5 0 0 0 0 20 14.5 14.5 0 0 0 0-20'}}, {'path': {'d': 'M2 12h20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileMinusCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-minus-corner'], 'items': [{'path': {'d': 'M20 14V8a2.4 2.4 0 0 0-.706-1.706l-3.588-3.588A2.4 2.4 0 0 0 14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'M14 18h6'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartBarIncreasing(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-bar-increasing'], 'items': [{'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'path': {'d': 'M7 11h8'}}, {'path': {'d': 'M7 16h12'}}, {'path': {'d': 'M7 6h3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignHorizontalSpaceAround(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-horizontal-space-around'], 'items': [{'rect': {'width': '6', 'height': '10', 'x': '9', 'y': '7', 'rx': '2'}}, {'path': {'d': 'M4 22V2'}}, {'path': {'d': 'M20 22V2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareSlash(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-slash'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'line': {'x1': '9', 'x2': '15', 'y1': '15', 'y2': '9'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def BookDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-book-down'], 'items': [{'path': {'d': 'M12 13V7'}}, {'path': {'d': 'M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H19a1 1 0 0 1 1 1v18a1 1 0 0 1-1 1H6.5a1 1 0 0 1 0-5H20'}}, {'path': {'d': 'm9 10 3 3 3-3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileXCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-x-corner'], 'items': [{'path': {'d': 'M11 22H6a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.588 3.588A2.4 2.4 0 0 1 20 8v5'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm15 17 5 5'}}, {'path': {'d': 'm20 17-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserRoundX(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-round-x'], 'items': [{'path': {'d': 'M2 21a8 8 0 0 1 11.873-7'}}, {'circle': {'cx': '10', 'cy': '8', 'r': '5'}}, {'path': {'d': 'm17 17 5 5'}}, {'path': {'d': 'm22 17-5 5'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def FileSearchCorner(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-file-search-corner'], 'items': [{'path': {'d': 'M11.1 22H6a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h8a2.4 2.4 0 0 1 1.706.706l3.589 3.588A2.4 2.4 0 0 1 20 8v3.25'}}, {'path': {'d': 'M14 2v5a1 1 0 0 0 1 1h5'}}, {'path': {'d': 'm21 22-2.88-2.88'}}, {'circle': {'cx': '16', 'cy': '17', 'r': '3'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def ChartGantt(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-chart-gantt'], 'items': [{'path': {'d': 'M10 6h8'}}, {'path': {'d': 'M12 16h6'}}, {'path': {'d': 'M3 3v16a2 2 0 0 0 2 2h16'}}, {'path': {'d': 'M8 11h7'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Archive(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-archive'], 'items': [{'rect': {'width': '20', 'height': '5', 'x': '2', 'y': '3', 'rx': '1'}}, {'path': {'d': 'M4 8v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8'}}, {'path': {'d': 'M10 12h4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Wifi(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-wifi'], 'items': [{'path': {'d': 'M12 20h.01'}}, {'path': {'d': 'M2 8.82a15 15 0 0 1 20 0'}}, {'path': {'d': 'M5 12.859a10 10 0 0 1 14 0'}}, {'path': {'d': 'M8.5 16.429a5 5 0 0 1 7 0'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def UserCheck(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-user-check'], 'items': [{'path': {'d': 'm16 11 2 2 4-4'}}, {'path': {'d': 'M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2'}}, {'circle': {'cx': '9', 'cy': '7', 'r': '4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def GripVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-grip-vertical'], 'items': [{'circle': {'cx': '9', 'cy': '12', 'r': '1'}}, {'circle': {'cx': '9', 'cy': '5', 'r': '1'}}, {'circle': {'cx': '9', 'cy': '19', 'r': '1'}}, {'circle': {'cx': '15', 'cy': '12', 'r': '1'}}, {'circle': {'cx': '15', 'cy': '5', 'r': '1'}}, {'circle': {'cx': '15', 'cy': '19', 'r': '1'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def AlignStartVertical(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-align-start-vertical'], 'items': [{'rect': {'width': '9', 'height': '6', 'x': '6', 'y': '14', 'rx': '2'}}, {'rect': {'width': '16', 'height': '6', 'x': '6', 'y': '4', 'rx': '2'}}, {'path': {'d': 'M2 2v20'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def Tally5(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-tally-5'], 'items': [{'path': {'d': 'M4 4v16'}}, {'path': {'d': 'M9 4v16'}}, {'path': {'d': 'M14 4v16'}}, {'path': {'d': 'M19 4v16'}}, {'path': {'d': 'M22 6 2 18'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def CalendarArrowDown(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-calendar-arrow-down'], 'items': [{'path': {'d': 'm14 18 4 4 4-4'}}, {'path': {'d': 'M16 2v4'}}, {'path': {'d': 'M18 14v8'}}, {'path': {'d': 'M21 11.354V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h7.343'}}, {'path': {'d': 'M3 10h18'}}, {'path': {'d': 'M8 2v4'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def SquareUser(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-square-user'], 'items': [{'rect': {'width': '18', 'height': '18', 'x': '3', 'y': '3', 'rx': '2'}}, {'circle': {'cx': '12', 'cy': '10', 'r': '3'}}, {'path': {'d': 'M7 21v-2a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield




import contextlib
from collections.abc import Generator

from .base import IconBase

                        
@contextlib.contextmanager
def History(**kwargs) -> Generator[None]:
    data = {'classes': ['lucide lucide-history'], 'items': [{'path': {'d': 'M3 12a9 9 0 1 0 9-9 9.75 9.75 0 0 0-6.74 2.74L3 8'}}, {'path': {'d': 'M3 3v5h5'}}, {'path': {'d': 'M12 7v5l4 2'}}]}
    with IconBase(data, **kwargs):
        pass
    yield
